#
# spec file for package python-jupyter_core-doc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} > 1320
%bcond_without pdf
%else
%bcond_with pdf
%endif

%bcond_without html

%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jupyter_core-doc
Version:        4.4.0
Release:        lp150.2.2
Summary:        Documentation for python-jupyter_core
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/jupyter/jupyter_core
Source:         https://files.pythonhosted.org/packages/source/j/jupyter_core/jupyter_core-%{version}.tar.gz
# PATCH-FIX-OPENSUSE -- use_rpms_paths.patch -- change paths so they are easy to replace at build time
Patch0:         use_rpms_paths.patch
BuildRequires:  %{python_module jupyter_core}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with tests}
# Test requirements
BuildRequires:  %{python_module pytest}
# Python 2.7 test requirements
BuildRequires:  python-mock
%endif
# Documentation requirements
BuildRequires:  %{python_module sphinxcontrib-github-alt}
%if %{with pdf} || %{with html}
BuildRequires:  python3-Sphinx
%endif
%if %{with pdf}
BuildRequires:  python3-Sphinx-latex
%endif
Provides:       %{name}-html = %{version}
Provides:       %{name}-pdf = %{version}
Obsoletes:      %{name}-html < %{version}
Obsoletes:      %{name}-pdf < %{version}
Provides:       %{python_module jupyter_core-doc = %{version}}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Documentation and help files for python-jupyter_core.

%prep
%setup -q -n jupyter_core-%{version}
%patch0 -p1
# Set the appropriate paths dynamically
sed -i "s|\"/usr/share/jupyter\"|\"%{_datadir}/jupyter\"|" jupyter_core/paths.py
sed -i "s|\"/etc/jupyter\"|\"%{_sysconfdir}/jupyter\"|" jupyter_core/paths.py
sed -i "s|(sys\.prefix, 'share', 'jupyter')|('%{_datadir}', 'jupyter')|" jupyter_core/paths.py
sed -i "s|(sys\.prefix, 'etc', 'jupyter')|('%{_sysconfdir}', 'jupyter')|" jupyter_core/paths.py

%build
# Build the documentation
pushd docs
%if %{with html}
make html
rm -rf build/html/.buildinfo
%endif
%if %{with pdf}
make latexpdf
%endif
popd

%install
mkdir -p %{buildroot}%{_docdir}/python-jupyter_core

%if %{with pdf}
cp docs/_build/latex/*.pdf %{buildroot}%{_docdir}/python-jupyter_core/
%endif

%if %{with html}
cp -r docs/_build/html %{buildroot}%{_docdir}/python-jupyter_core/
%endif

cp -r examples %{buildroot}%{_docdir}/python-jupyter_core/
%fdupes %{buildroot}%{_docdir}/python-jupyter_core/

%if %{with tests}
%check
# test_migrate requires files not found in the package
pushd jupyter_core/tests
rm test_migrate.py
%python_expand py.test-%{$python_bin_suffix}
popd
%endif

%files
%defattr(-,root,root,-)
%doc COPYING.md
%{_docdir}/python-jupyter_core/

%changelog
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Wed Nov 22 2017 arun@gmx.de
- require sphinxcontrib-github-alt
- update to version 4.4.0:
  * jupyter troubleshoot gets the list of packages from the Python
    environment it's in, by using sys.executable to call pip list
    (:ghpull:`104`).
  * Added utility function ensure_dir_exists, and switched to using it
    over the one from ipython_genutils, which does permissions wrong
    (:ghpull:`113`).
  * Avoid creating the ~/.ipython directory when checking if it exists
    for config migration (:ghpull:`118`).
  * Fix mistaken description in zsh completions (:ghpull:`98`).
  * Fix subcommand tests on Windows (:ghpull:`103`).
  * The README now describes how to work on jupyter_core and build the
    docs (:ghpull:`110`).
  * Fix a broken link to a release in the docs (:ghpull:`109`).
* Wed Sep 20 2017 toddrme2178@gmail.com
- Set configuration and data paths to be correct for any
  Linux distribution. This is done by using sed to replace
  hard-coded values with those provided by rpm.
  * Add use_rpms_paths.patch to make the paths easier to replace.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Remove version_specific_dirs.patch.
  The Python3 jupyter implementation will be used for directories.
* Fri Mar 31 2017 toddrme2178@gmail.com
- Add version_specific_dirs.patch
  Uses python version-specific directories to avoid conflicts.
- Install the directories used for system-side settings and data so
  they are properly owned by this package.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 4.3.0
  * Add `JUPYTER_NO_CONFIG` environment variable for disabling all
    Jupyter configuration.
  * More detailed error message when failing to launch subcommands.
- Update to 4.2.1
  * Fix error message on Windows when subcommand not found.
  * Correctly display PATH in ``jupyter troubleshoot`` on Windows.
- Update to 4.2.0
  * Make :command:`jupyter` directory top priority in search path
    for subcommands, so that :command:`jupyter-subcommand` next to
    :command:`jupyter` will always be picked if present.
  * Avoid using ``shell=True`` for subcommand dispatch on Windows.
- Update to 4.1.1
  * Include symlink directory and real location on subcommand PATH
    when :file:`jupyter` is a symlink.
- Update to 4.1.0
  * Add ``jupyter.py`` module, so that :command:`python -m jupyter`
    always works.
  * Add prototype ``jupyter troubleshoot`` command for displaying
    environment info.
  * Ensure directory containing ``jupyter`` executable is included
    when dispatching subcommands.
  * Unicode fixes for Legacy Python.
* Wed Feb 17 2016 toddrme2178@gmail.com
- Simplify the tests for whether to build pdf documentation
* Wed Feb 17 2016 toddrme2178@gmail.com
- Split documentation to speed up building.
  This is a dependency of a lot of other packages, and the
  dependencies for the documentation are very heavy.  So build
  the documentation separately to avoid holding up the build
  process.
* Thu Oct  1 2015 toddrme2178@gmail.com
- Build documentation
* Wed Sep 23 2015 toddrme2178@gmail.com
- update to version 4.0.6:
  * fix typo preventing migration when custom.css is missing
- update to version 4.0.5:
  * fix subcommands on Windows (yes, again)
  * fix migration when custom.js/css are not present
* Mon Aug 24 2015 toddrme2178@gmail.com
- Update to 4.0.4
  * ensure version is printed to stdout …
  * remove file-extension from subcommand list on Windows
- Update requirements
* Fri Aug 14 2015 toddrme2178@gmail.com
- Update to 4.0.3
  * use raw_input on Python 2
  * Use setuptools entry points when setuptools in use
  * Use instances of traits instead of trait classes
- Fix package naming consistency
* Fri Aug 14 2015 toddrme2178@gmail.com
- Fix update-alternatives usage
* Thu Aug 13 2015 toddrme2178@gmail.com
- Update dependency names
* Tue Jul 21 2015 jennings@neuro.bzm
- Initial version
